(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     36791,       1019]
NotebookOptionsPosition[     36490,       1006]
NotebookOutlinePosition[     36835,       1021]
CellTagsIndexPosition[     36792,       1018]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Here", " ", "we", " ", "quantify", " ", "the", " ", "welfare", " ", 
     "cost", " ", "of", " ", "inflation", " ", "in", " ", "BC"}], ",", " ", 
    RowBox[{
    "BCW", " ", "and", " ", "LW", " ", "for", " ", "an", " ", "annual", " ", 
     RowBox[{"model", ".", " ", "The"}], " ", "parameters", " ", "A"}], ",", 
    " ", 
    RowBox[{
     RowBox[{
     "DD", " ", "and", " ", "alpha", " ", "are", " ", "calibrated", " ", 
      "for", " ", "a", " ", "CRS", " ", "production", " ", "function", " ", 
      "for", " ", 
      RowBox[{"banks", ".", " ", "We"}], " ", "are", " ", "assuming", " ", 
      "that", " ", "at", " ", "rstar"}], "=", 
     RowBox[{
     "0", " ", "depositors", " ", "choose", " ", "not", " ", "to", " ", 
      RowBox[{"deposit", "."}]}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Print", "[", "\"\<PART 1: LOAD PARAMETERS USED\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<discount factor\>\"", "]"}], "\n", 
   RowBox[{"beta", "=", "0.96"}], "\n", 
   RowBox[{
   "Print", "[", "\"\<delta (exponent in mkt1 utility function)\>\"", "]"}], 
   "\n", 
   RowBox[{"delta", " ", "=", "0.99999"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\< b (constant in mkt1 utility function)\>\"", "]"}], 
   "\n", 
   RowBox[{"b", "=", "0.00001"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<psi (exponent in mkt1 cost function)\>\"", "]"}], "\n", 
   RowBox[{"psi", "=", "1.001"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<Rate of growth of money stock at Friedman rule\>\"", 
    "]"}], "\n", 
   RowBox[{"muF", "=", "beta"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<interest rate at Friedman rule\>\"", "]"}], 
   "\n", 
   RowBox[{"intF", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"muF", "-", "beta"}], ")"}], "/", "beta"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<Max rate of growth of money stock we want to consider for our \
calculations\>\"", "]"}], "\n", 
   RowBox[{"mumax", "=", "1.5"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<Max interest rate\>\"", "]"}], "\n", 
   RowBox[{"intmax", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"mumax", "-", "beta"}], ")"}], "/", "beta"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<calibrated alpha, probability of being a buyer in mkt 1\>\"", "]"}], 
   "\n", 
   RowBox[{"alpha", "=", "0.54768"}], "\n", 
   RowBox[{
   "Print", "[", "\"\<A, calibrated TFP in bank production function\>\"", 
    "]"}], "\n", 
   RowBox[{"A", "=", "4.02385"}], "\n", 
   RowBox[{
   "Print", "[", 
    "\"\<calibrated D, constant in front of mkt 2 log utility\>\"", "]"}], 
   "\n", 
   RowBox[{"DD", "=", "4.98832"}], "\n", 
   RowBox[{"Print", "[", "\"\<mu s.t. deposit rate r*>0\>\"", "]"}], "\n", 
   RowBox[{"mustar", "=", 
    RowBox[{"beta", "+", 
     RowBox[{"alpha", "*", 
      RowBox[{"beta", "/", "A"}]}]}]}], "\n", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<PART 2: VARIABLES AT FRIEDMAN RULE\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", "  ", "in", " ", "BC", " ", "at", " ", 
     "Friedman", " ", "rule"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qbcF", ":=", 
    RowBox[{"ttbcF", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttbcF", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttbcF"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"muF", "/", "beta"}], "-", "1"}], ")"}], "/", 
              "alpha"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttbcF", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "in", " ", 
     "BC", " ", "at", " ", "Friedman", " ", "rule"}], "*)"}], "\n", 
   RowBox[{"nbcF", ":=", 
    RowBox[{"alpha", " ", "*", 
     RowBox[{"qbcF", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "welfare", " ", "in", " ", "BC", " ", "at", " ", "Friedman", " ", 
     "rule"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wbcF", ":=", 
    RowBox[{
     RowBox[{"alpha", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "qlwF", ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
          RowBox[{"(", 
           RowBox[{"b", "^", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", "nlwF", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}], "+", 
     RowBox[{"DD", "*", 
      RowBox[{"Log", "[", "DD", "]"}]}], "-", "DD"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", " ", "in", " ", "LW", " ", "at", " ", 
     "Friedman", " ", "rule"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qlwF", ":=", 
    RowBox[{"ttlwF", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttlwF", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttlwF"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"muF", "/", "beta"}], "-", "1"}], ")"}], "/", 
              "alpha"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttlwF", ",", "0.1"}], "}"}]}], "]"}]}]}], "\n", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "in", " ", 
     "LW", " ", "at", " ", "Friedman", " ", "rule"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"nlwF", ":=", 
    RowBox[{"alpha", " ", "*", 
     RowBox[{"qlwF", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "welfare", " ", "in", " ", "LW", " ", "at", " ", "Friedman", " ", 
     "rule"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wlwF", ":=", 
    RowBox[{
     RowBox[{"alpha", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "qlwF", ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
          RowBox[{"(", 
           RowBox[{"b", "^", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", "nlwF", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}], "+", 
     RowBox[{"DD", "*", 
      RowBox[{"Log", "[", "DD", "]"}]}], "-", "DD"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", " ", "in", " ", "BCW", " ", "at", " ", 
     "Friedman", " ", "rule"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qbcwF", ":=", 
    RowBox[{"ttbcwF", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttbcwF", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttbcwF"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"muF", "/", "beta"}], "-", "1"}], ")"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttbcwF", ",", "0.1"}], "}"}]}], "]"}]}]}], "\n", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "in", " ", 
     "BCW", " ", "at", " ", "Friedman", " ", "rule"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"nbcwF", ":=", 
    RowBox[{"alpha", " ", "*", 
     RowBox[{"qbcwF", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"welfare", " ", "in", " ", "BCW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wbcwF", ":=", 
    RowBox[{
     RowBox[{"alpha", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "qbcwF", ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
          RowBox[{"(", 
           RowBox[{"b", "^", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", "nbcF", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}], "+", 
     RowBox[{"DD", "*", 
      RowBox[{"Log", "[", "DD", "]"}]}], "-", "DD"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<PART 3: COMPUTE WELFARE COST OF INFLATION VS FRIEDMAN RULE IN BC, \
BCW, LW AT DIFFERENT LEVELS OF INFLATION\>\"", "]"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Scenario", " ", "when", " ", "deposit", " ", "rate", " ", "when", " ", 
      "r", "*"}], ">", "0"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "labor", " ", "in", " ", "production", " ", "sector", " ", "for", " ", 
      "generic", " ", "interest", " ", "rate", " ", "in", " ", "BC", " ", 
      "when", " ", "deposit", " ", "rate", " ", "r", "*"}], ">", "0"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qbc", ":=", 
    RowBox[{"ttbc", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttbc", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttbc", "*", 
                RowBox[{"(", 
                 RowBox[{"A", "+", "1", "-", "alpha"}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "alpha"}], ")"}], "*", "A"}], ")"}]}], 
             ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}], "/", "A"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttbc", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "in", " ", 
     "BC19"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"nbc", ":=", 
    RowBox[{"alpha", "*", 
     RowBox[{"qbc", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"labor", " ", "in", " ", "banking", " ", "sector", " ", 
     RowBox[{"w", "/", " ", "banks"}], " ", "in", " ", "BC19"}], " ", "*)"}], 
   "\n", 
   RowBox[{"nBbc", ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "alpha"}], ")"}], "*", 
     RowBox[{"nbc", "/", "A"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"1", "-", " ", 
      RowBox[{
      "welfare", " ", "cost", " ", "of", " ", "inflation", " ", "for", " ", 
       "generic", " ", "interest", " ", "rate", " ", "in", " ", "BC", " ", 
       "when", " ", "deposit", " ", "rate", " ", "r", "*"}]}], ">", 
     RowBox[{"0", "*"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wcibcbarF", ":=", 
    RowBox[{"ttwcibcF", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ttwcibcF", "*", "qbcF"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
               RowBox[{"(", 
                RowBox[{"b", "^", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "alpha"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "nbcF", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}],
           "+", 
          RowBox[{"DD", "*", 
           RowBox[{"Log", "[", 
            RowBox[{"ttwcibcF", "*", "DD"}], "]"}]}], "-", "DD", "-", 
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", "qbc", ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
               RowBox[{"(", 
                RowBox[{"b", "^", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "alpha"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"nbc", "+", "nBbc"}], ")"}], "^", "psi"}], ")"}], "/", 
            "psi"}]}], "-", 
          RowBox[{"DD", "*", 
           RowBox[{"Log", "[", "DD", "]"}]}], "+", "DD"}], "\[Equal]", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttwcibcF", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Scenario", " ", "when", " ", "deposit", " ", "rate", " ", "when", " ", 
      "r"}], "*=", "0"}], "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "mkt1", " ", "consumption", " ", "for", " ", "generic", " ", "interest", 
      " ", "rate", " ", "in", " ", "BC", " ", "when", " ", "deposit", " ", 
      "rate", " ", "r"}], "*=", "0"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qbcrzero", ":=", 
    RowBox[{"ttbcrzero", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttbcrzero", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttbcrzero"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}], "/", 
              "alpha"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttbcrzero", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "labor", " ", "in", " ", "production", " ", "sector", " ", "for", " ", 
      "generic", " ", "interest", " ", "rate", " ", "in", " ", "BC", " ", 
      "when", " ", "deposit", " ", "rate", " ", "r"}], "*=", "0"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"nbcrzero", ":=", 
    RowBox[{"alpha", " ", "*", 
     RowBox[{"qbcrzero", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{
      "welfare", " ", "cost", " ", "of", " ", "inflation", " ", "for", " ", 
       "generic", " ", "interest", " ", "rate", " ", "in", " ", "BC", " ", 
       "when", " ", "deposit", " ", "rate", " ", "r"}]}], "*=", "0"}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{"wcibcrzerobar", ":=", 
    RowBox[{"ttwcibcrzero", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ttwcibcrzero", "*", "qbcF"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
               RowBox[{"(", 
                RowBox[{"b", "^", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "alpha"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "nbcF", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}],
           "+", 
          RowBox[{"DD", "*", 
           RowBox[{"Log", "[", 
            RowBox[{"ttwcibcrzero", "*", "DD"}], "]"}]}], "-", "DD", "-", 
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", "qbcrzero", ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
               RowBox[{"(", 
                RowBox[{"b", "^", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "alpha"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "nbcrzero", ")"}], "^", "psi"}], ")"}], "/", 
            "psi"}]}], "-", 
          RowBox[{"DD", "*", 
           RowBox[{"Log", "[", "DD", "]"}]}], "+", "DD"}], "\[Equal]", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttwcibcrzero", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Construct", " ", "welfare", " ", "variable", " ", "in", " ", "LW"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", " ", "for", " ", "generic", " ", "interest", 
     " ", "rate", " ", "in", " ", "LW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qlw", ":=", 
    RowBox[{"ttlw", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttlw", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttlw"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}], "/", 
              "alpha"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttlw", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "for", " ", 
     "generic", " ", "interest", " ", "rate", " ", "in", " ", "LW"}], "*)"}], 
   "\n", 
   RowBox[{"nlw", ":=", 
    RowBox[{"alpha", " ", "*", 
     RowBox[{"qlw", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", "-", 
     RowBox[{
     "welfare", " ", "cost", " ", "of", " ", "inflation", " ", "for", " ", 
      "generic", " ", "interest", " ", "rate", " ", "in", " ", "LW"}]}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wcilwbarF", ":=", 
    RowBox[{"ttwcilwF", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ttwcilwF", "*", "qlwF"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
               RowBox[{"(", 
                RowBox[{"b", "^", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "alpha"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "nlwF", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}],
           "+", 
          RowBox[{"DD", "*", 
           RowBox[{"Log", "[", 
            RowBox[{"ttwcilwF", "*", "DD"}], "]"}]}], "-", "DD", "-", 
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", "qlw", ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
               RowBox[{"(", 
                RowBox[{"b", "^", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "alpha"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "nlw", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}], 
          "-", 
          RowBox[{"DD", "*", 
           RowBox[{"Log", "[", "DD", "]"}]}], "+", "DD"}], "\[Equal]", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttwcilwF", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Construct", " ", "welfare", " ", "variable", " ", "in", " ", "BCW"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", " ", "for", " ", "generic", " ", "interest", 
     " ", "rate", " ", "in", " ", "BCW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qbcw", ":=", 
    RowBox[{"ttbcw", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttbcw", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttbcw"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttbcw", ",", "0.1"}], "}"}]}], "]"}]}]}], "\n", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "for", " ", 
     "generic", " ", "interest", " ", "rate", " ", "in", " ", "BCW"}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{"nbcw", ":=", 
    RowBox[{"alpha", " ", "*", 
     RowBox[{"qbcw", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", "-", 
     RowBox[{
     "welfare", " ", "cost", " ", "of", " ", "inflation", " ", "for", " ", 
      "generic", " ", "interest", " ", "rate", " ", "in", " ", "BCW"}]}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wcibcwbarF", ":=", 
    RowBox[{"ttwcibcwF", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ttwcibcwF", "*", "qbcwF"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
               RowBox[{"(", 
                RowBox[{"b", "^", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "alpha"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "nbcwF", ")"}], "^", "psi"}], ")"}], "/", 
            "psi"}]}], "+", 
          RowBox[{"DD", "*", 
           RowBox[{"Log", "[", 
            RowBox[{"ttwcibcwF", "*", "DD"}], "]"}]}], "-", "DD", "-", 
          RowBox[{"alpha", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", "qbcw", ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
               RowBox[{"(", 
                RowBox[{"b", "^", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "alpha"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "nbcw", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}],
           "-", 
          RowBox[{"DD", "*", 
           RowBox[{"Log", "[", "DD", "]"}]}], "+", "DD"}], "\[Equal]", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttwcibcwF", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "welfare", " ", "cost", " ", "of", " ", "inflation", " ", "for", " ", 
      "generic", " ", "interest", " ", "rate", " ", "in", " ", "BC", " ", 
      RowBox[{"w", "/", " ", "r"}], "*"}], ">", "0"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"wcibcF", ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "wcibcbarF"}], ")"}], "*", "100"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "welfare", " ", "cost", " ", "of", " ", "inflation", " ", "for", " ", 
      "generic", " ", "interest", " ", "rate", " ", "in", " ", "BC", " ", 
      RowBox[{"w", "/", " ", "r"}]}], "*=", "0"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"wcibcrzero", ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "wcibcrzerobar"}], ")"}], "*", "100"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "welfare", " ", "cost", " ", "of", " ", "inflation", " ", "for", " ", 
     "generic", " ", "interest", " ", "rate", " ", "in", " ", "BCW"}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{"wcibcwF", ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "wcibcwbarF"}], ")"}], "*", "100"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "welfare", " ", "cost", " ", "of", " ", "inflation", " ", "for", " ", 
     "generic", " ", "interest", " ", "rate", " ", "in", " ", "LW"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"wcilwF", ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "wcilwbarF"}], ")"}], "*", "100"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<PLOT wci\>\"", "]"}], "\[IndentingNewLine]", 
   RowBox[{"image", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Piecewise", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"wcibcrzero", ",", " ", 
             RowBox[{"mu", "<", "mustar"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"wcibcF", ",", " ", 
             RowBox[{"mu", ">", "mustar"}]}], "}"}]}], "}"}], "]"}], "}"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mu", ",", " ", "muF", ",", "mumax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", " ", 
        RowBox[{"Blue", ",", " ", "Blue"}], "}"}]}], ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<wci\>\"", ",", "\"\<ell\>\""}], "}"}]}], ",", " ", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<BC wci\>\"", ",", " ", "\"\<BC wci\>\""}], "}"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<PRINT WELFARE COST OF INFLATION VS FRIEDMAN RULE IN BC W/ r*=0 (all \
mu levels w r*=0)\>\"", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Print", "[", "wcibcrzero", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"mu", ",", "muF", ",", "mustar", ",", "0.001"}], "}"}]}], "]"}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<PRINT WELFARE COST OF INFLATION VS FRIEDMAN RULE IN BC W/ r*>0\>\"", 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Print", "[", "wcibcF", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"mu", ",", "mustar", ",", "mumax", ",", " ", "0.001"}], "}"}]}],
     "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Print", "[", 
      "\"\<PRINT WELFARE COST OF INFLATION VS FRIEDMAN RULE IN BCW\>\"", 
      "]"}], "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"Print", "[", "wcibcwF", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"mu", ",", "1.20", ",", " ", "1.20"}], "}"}]}], "]"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
     "Print", "[", 
      "\"\<PRINT WELFARE COST OF INFLATION VS FRIEDMAN RULE IN LW\>\"", "]"}],
      "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"Print", "[", "wcilwF", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"mu", ",", " ", "1.20", ",", " ", "1.20"}], "}"}]}], "]"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "Print", "[", "\"\<PRINT q IN BC W/ r*=0 (all mu levels w r*=0)\>\"", 
        "]"}], "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Print", "[", "qbcrzero", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"mu", ",", "muF", ",", "mustar", ",", "0.01"}], "}"}]}], 
        "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<PRINT q IN LW\>\"", "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Print", "[", "qlw", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"mu", ",", " ", "muF", ",", "mumax", ",", "0.01"}], "}"}]}],
         "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<PRINT q IN BC W/ r*>0\>\"", "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Print", "[", "qbc", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"mu", ",", " ", "mustar", ",", "mumax", ",", "0.01"}], 
          "}"}]}], "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<PRINT q IN BCW\>\"", "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"Print", "[", "qbcw", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"mu", ",", " ", "muF", ",", "mumax", ",", "0.01"}], "}"}]}],
         "]"}]}]}]}]}]}]}]], "Input",ExpressionUUID->"c784bb7f-14ae-4706-a840-\
e4cd26db3215"]
},
WindowSize->{1520, 805},
WindowMargins->{{2154, Automatic}, {Automatic, 53}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 35928, 984, 2860, "Input",ExpressionUUID->"c784bb7f-14ae-4706-a840-e4cd26db3215"]
}
]
*)

(* End of internal cache information *)

