(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     13768,        394]
NotebookOptionsPosition[     13467,        381]
NotebookOutlinePosition[     13812,        396]
CellTagsIndexPosition[     13769,        393]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Here", " ", "I", " ", "am", " ", "quantifying", " ", "welfare", " ", 
     "for", " ", "an", " ", "annual", " ", "model", " ", "in", " ", "BC", 
     RowBox[{"(", 
      RowBox[{"w", "/", " ", "CRS"}], ")"}]}], ",", " ", 
    RowBox[{"BCW", " ", "and", " ", "LW"}], ",", " ", 
    RowBox[{
    "with", " ", "the", " ", "parameters", " ", "calibrated", " ", "for", " ",
      "BC"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Print", "[", "\"\<PART 1: LOAD PARAMETERS USED\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<discount factor\>\"", "]"}], "\n", 
   RowBox[{"beta", "=", "0.96"}], "\n", 
   RowBox[{
   "Print", "[", "\"\<delta (exponent in mkt1 utility function)\>\"", "]"}], 
   "\n", 
   RowBox[{"delta", " ", "=", "0.99999"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\< b (constant in mkt1 utility function)\>\"", "]"}], 
   "\n", 
   RowBox[{"b", "=", "0.00001"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<psi (exponent in mkt1 cost function)\>\"", "]"}], "\n", 
   RowBox[{"psi", "=", "1.1"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<Rate of growth of money stock at Friedman rule\>\"", 
    "]"}], "\n", 
   RowBox[{"muF", "=", "beta"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<Max rate of growth of money stock we want to consider for our \
plots\>\"", "]"}], "\n", 
   RowBox[{"mumax", "=", "1.5"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<Max interest rate\>\"", "]"}], "\n", 
   RowBox[{"intmax", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"mumax", "-", "beta"}], ")"}], "/", "beta"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<calibrated alpha, probability of being a buyer in mkt 1\>\"", "]"}], 
   "\n", 
   RowBox[{"alpha", "=", "0.6313791273501956"}], "\n", 
   RowBox[{
   "Print", "[", 
    "\"\<calibrated D, constant in front of mkt 2 log utility\>\"", "]"}], 
   "\n", 
   RowBox[{"DD", "=", "2.737882711404472"}], "\n", 
   RowBox[{
   "Print", "[", "\"\<A, calibrated TFP in bank production function\>\"", 
    "]"}], "\n", 
   RowBox[{"A", "=", "53.0565"}], "\n", 
   RowBox[{"Print", "[", "\"\<mu s.t. r*>0\>\"", "]"}], "\n", 
   RowBox[{"mustar", "=", 
    RowBox[{"beta", "+", 
     RowBox[{"alpha", "*", 
      RowBox[{"beta", "/", "A"}]}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"PART", " ", "2"}], ":", " ", 
     RowBox[{
     "DEFINE", " ", "WELFARE", " ", "IN", " ", "BC19", " ", "AT", " ", 
      "DIFFERENT", " ", "LEVELS", " ", "OF", " ", "INTEREST", " ", "RATE", 
      " ", "WHEN", " ", "CWH"}]}], "*)"}], "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"mkt1", " ", "consumption", "  ", "in", " ", "BC19"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qbc", ":=", 
    RowBox[{"ttbc", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttbc", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttbc", "*", 
                RowBox[{"(", 
                 RowBox[{"A", "+", "1", "-", "alpha"}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "alpha"}], ")"}], "*", "A"}], ")"}]}], 
             ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}], "/", "A"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttbc", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "in", " ", 
     "BC19"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"nbc", ":=", 
    RowBox[{"alpha", "*", 
     RowBox[{"qbc", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\n", 
   RowBox[{"(*", 
    RowBox[{"labor", " ", "in", " ", "banking", " ", "sector", " ", 
     RowBox[{"w", "/", " ", "banks"}], " ", "in", " ", "BC19"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"nBbc", ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "alpha"}], ")"}], "*", 
     RowBox[{"nbc", "/", "A"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"welfare", " ", "in", " ", "BC19"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"wbc", ":=", 
    RowBox[{
     RowBox[{"alpha", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "qbc", ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
          RowBox[{"(", 
           RowBox[{"b", "^", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"nbc", "+", "nBbc"}], ")"}], "^", "psi"}], ")"}], "/", 
       "psi"}]}], "+", 
     RowBox[{"DD", "*", 
      RowBox[{"Log", "[", "DD", "]"}]}], "-", "DD"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"PART", " ", "3"}], ":", " ", 
     RowBox[{
     "DEFINE", " ", "WELFARE", " ", "IN", " ", "BCW", " ", "AT", " ", 
      "DIFFERENT", " ", "LEVELS", " ", "OF", " ", "INTEREST", " ", "RATE"}]}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", " ", "for", " ", "generic", " ", "interest", 
     " ", "rate", " ", "in", " ", "BCW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qbcw", ":=", 
    RowBox[{"ttbcw", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttbcw", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttbcw"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttbcw", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "for", " ", 
     "generic", " ", "interest", " ", "rate", " ", "in", " ", "BCW"}], "*)"}],
    "\n", 
   RowBox[{"nbcw", ":=", 
    RowBox[{"alpha", " ", "*", 
     RowBox[{"qbcw", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"welfare", " ", "in", " ", "BCW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wbcw", ":=", 
    RowBox[{
     RowBox[{"alpha", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "qbcw", ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
          RowBox[{"(", 
           RowBox[{"b", "^", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", "nbcw", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}], "+", 
     RowBox[{"DD", "*", 
      RowBox[{"Log", "[", "DD", "]"}]}], "-", "DD"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"PART", " ", "4"}], ":", " ", 
     RowBox[{
     "DEFINE", " ", "WELFARE", " ", "IN", " ", "LW", " ", "AT", " ", 
      "DIFFERENT", " ", "LEVELS", " ", "OF", " ", "INTEREST", " ", "RATE"}]}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", " ", "for", " ", "generic", " ", "interest", 
     " ", "rate", " ", "in", " ", "LW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qlw", ":=", 
    RowBox[{"ttlw", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ttlw", "+", "b", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"alpha", "*", "ttlw"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "-", "alpha"}], ")"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "psi"}], ")"}], "/", "delta"}], ")"}]}], 
           ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}], "/", 
              "alpha"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "/", "delta"}], ")"}]}]}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttlw", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "labor", " ", "in", " ", "production", " ", "sector", " ", "for", " ", 
     "generic", " ", "interest", " ", "rate", " ", "in", " ", "LW"}], "*)"}], 
   "\n", 
   RowBox[{"nlw", ":=", 
    RowBox[{"alpha", " ", "*", 
     RowBox[{"qlw", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"welfare", " ", "in", " ", "BCW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wlw", ":=", 
    RowBox[{
     RowBox[{"alpha", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "qlw", ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
          RowBox[{"(", 
           RowBox[{"b", "^", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", "nlw", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}], "+", 
     RowBox[{"DD", "*", 
      RowBox[{"Log", "[", "DD", "]"}]}], "-", "DD"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<PRINT WELFARE IN BC19\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Print", "[", "wbc", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"mu", ",", " ", "muF", ",", "3", ",", "0.0001"}], "}"}]}], 
    "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<PRINT WELFARE IN BCW\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Print", "[", "wbcw", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"mu", ",", " ", "muF", ",", "3", ",", "0.0001"}], "}"}]}], 
    "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<PRINT WELFARE IN LW\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Print", "[", "wlw", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"mu", ",", " ", "muF", ",", "3", ",", "0.0001"}], "}"}]}], 
    "]"}]}]}]], "Input",ExpressionUUID->"96f1cc73-b87b-4133-94df-\
a8f29649eb48"]
},
WindowSize->{1520, 805},
WindowMargins->{{2093, Automatic}, {Automatic, 71}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 12905, 359, 1245, "Input",ExpressionUUID->"96f1cc73-b87b-4133-94df-a8f29649eb48"]
}
]
*)

(* End of internal cache information *)

