(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     20528,        583]
NotebookOptionsPosition[     20226,        570]
NotebookOutlinePosition[     20572,        585]
CellTagsIndexPosition[     20529,        582]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Here", " ", "I", " ", "am", " ", "quantifying", " ", "welfare", " ", 
    "for", " ", "BC", " ", 
    RowBox[{"w", "/", " ", "bargaining"}], " ", "in", " ", "the", " ", "DM"}],
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Print", "[", "\"\<PART 1: LOAD PARAMETERS USED\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<discount factor\>\"", "]"}], "\n", 
   RowBox[{"beta", "=", "0.96"}], "\n", 
   RowBox[{
   "Print", "[", "\"\<delta (exponent in mkt1 utility function)\>\"", "]"}], 
   "\n", 
   RowBox[{"delta", " ", "=", "0.99999"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\< b (constant in mkt1 utility function)\>\"", "]"}], 
   "\n", 
   RowBox[{"b", "=", "0.00001"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<psi (exponent in mkt1 cost function)\>\"", "]"}], "\n", 
   RowBox[{"psi", "=", "1.1"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<Rate of growth of money stock at Friedman rule\>\"", 
    "]"}], "\n", 
   RowBox[{"muF", "=", "beta"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<Max rate of growth of money stock we want to consider for our \
plots\>\"", "]"}], "\n", 
   RowBox[{"mumax", "=", "1.5"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<Max interest rate\>\"", "]"}], "\n", 
   RowBox[{"intmax", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"mumax", "-", "beta"}], ")"}], "/", "beta"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<calibrated alpha, probability of being a buyer in mkt 1\>\"", "]"}], 
   "\n", 
   RowBox[{"alpha", "=", "0.6313791273501956`"}], "\n", 
   RowBox[{
   "Print", "[", 
    "\"\<calibrated D, constant in front of mkt 2 log utility\>\"", "]"}], 
   "\n", 
   RowBox[{"DD", "=", "2.737882711404472"}], "\n", 
   RowBox[{
   "Print", "[", "\"\<A, calibrated TFP in bank production function\>\"", 
    "]"}], "\n", 
   RowBox[{"A", "=", "53.0565"}], "\n", 
   RowBox[{"Print", "[", "\"\<mu s.t. r*>0\>\"", "]"}], "\n", 
   RowBox[{"mustar", "=", 
    RowBox[{"beta", "+", 
     RowBox[{"alpha", "*", 
      RowBox[{"beta", "/", "A"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<bargaining power\>\"", "]"}], "\n", 
   RowBox[{"theta", "=", "0.2"}], "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", "mu", "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
      "Print", "[", "\"\<define gross interest rate on illiquid bond\>\"", 
       "]"}], "\[IndentingNewLine]", 
      RowBox[{"inte", "[", "mu_", "]"}]}], ":=", 
     RowBox[{"mu", "/", "beta"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "DEFINE", " ", "WELFARE", " ", "IN", " ", "LW", " ", "AT", " ", 
     "DIFFERENT", " ", "LEVELS", " ", "OF", " ", "INTEREST", " ", "RATE", " ", 
     RowBox[{"W", "/", " ", "BARGAINING"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<define phi prime from bargaining problem\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Phiprime", "[", "ttlw_", "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"ttlw", "+", "b"}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"-", "delta"}], ")"}]}], ")"}], " ", "*", 
         RowBox[{"(", 
          RowBox[{"ttlw", "^", 
           RowBox[{"(", 
            RowBox[{"psi", "-", "1"}], ")"}]}], ")"}], "*", 
         RowBox[{"(", " ", 
          RowBox[{
           RowBox[{"theta", " ", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ttlw", "+", "b"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"-", "delta"}], ")"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "theta"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"ttlw", "^", 
              RowBox[{"(", 
               RowBox[{"psi", "-", "1"}], ")"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"theta", "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", "theta"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"ttlw", "+", "b"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
              RowBox[{"b", "^", 
               RowBox[{"(", 
                RowBox[{"1", "-", "delta"}], ")"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ttlw", "^", 
              RowBox[{"{", "psi", "}"}]}], ")"}], "/", 
            RowBox[{"(", "psi", ")"}]}]}], " ", ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ttlw", "+", "b"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"-", "delta"}], ")"}]}], ")"}], " ", "*", 
            RowBox[{"(", 
             RowBox[{"psi", "-", "1"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"ttlw", "^", 
              RowBox[{"(", 
               RowBox[{"psi", "-", "2"}], ")"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ttlw", "^", 
              RowBox[{"(", 
               RowBox[{"psi", "-", "1"}], ")"}]}], ")"}], "*", "delta", "*", 
            " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ttlw", "+", "b"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"delta", "+", "1"}], ")"}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"theta", "*", 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ttlw", "+", "b"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"-", "delta"}], ")"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "theta"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"ttlw", "^", 
             RowBox[{"(", 
              RowBox[{"psi", "-", "1"}], ")"}]}], ")"}]}]}], ")"}], "^", 
        "2"}], ")"}]}], ")"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", " ", "for", " ", "generic", " ", "interest", 
     " ", "rate", " ", "in", " ", "LW", " ", 
     RowBox[{"W", "/", " ", "BARGAINING"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qlw", ":=", 
    RowBox[{"ttlw", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"ttlw", "+", "b"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"-", "delta"}], ")"}]}], ")"}], "-", 
          RowBox[{
           RowBox[{"Phiprime", "[", "ttlw", "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}], "/", 
              "alpha"}]}], ")"}]}]}], "\[Equal]", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ttlw", ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"welfare", " ", "in", " ", "LW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wlw", ":=", 
    RowBox[{
     RowBox[{"alpha", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "qlw", ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
          RowBox[{"(", 
           RowBox[{"b", "^", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", "qlw", ")"}], "^", "psi"}], ")"}], "/", "psi"}]}], "+", 
     RowBox[{"DD", "*", 
      RowBox[{"Log", "[", "DD", "]"}]}], "-", "DD"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "DEFINE", " ", "WELFARE", " ", "IN", " ", "BC", " ", "AT", " ", 
     "DIFFERENT", " ", "LEVELS", " ", "OF", " ", "INTEREST", " ", "RATE", " ", 
     RowBox[{"W", "/", " ", "BARGAINING"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"Print", "[", "\"\<define nB\>\"", "]"}], "\[IndentingNewLine]", 
      RowBox[{"nB", "[", "ttbc_", "]"}]}], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{"ttbc", "/", "A"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<define aggregate labor N\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NN", "[", "ttbc", "]"}], "=", 
    RowBox[{"ttbc", "+", "nB"}]}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<define phi prime from bargaining problem\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Phiprimebcc", "[", "ttbc", "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"ttbc", "+", "b"}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"-", "delta"}], ")"}]}], ")"}], " ", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"NN", "[", "ttbc", "]"}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"psi", "-", "1"}], ")"}]}], ")"}], "*", 
         RowBox[{"(", " ", 
          RowBox[{
           RowBox[{"theta", " ", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ttbc", "+", "b"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"-", "delta"}], ")"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "theta"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"NN", "[", "ttbc", "]"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"psi", "-", "1"}], ")"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"theta", "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", "theta"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"ttbc", "+", "b"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
              RowBox[{"b", "^", 
               RowBox[{"(", 
                RowBox[{"1", "-", "delta"}], ")"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"NN", "[", "ttbc", "]"}], ")"}], "^", 
              RowBox[{"(", "psi", ")"}]}], ")"}], "/", 
            RowBox[{"(", "psi", ")"}]}]}], " ", ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ttbc", "+", "b"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"-", "delta"}], ")"}]}], ")"}], " ", "*", 
            RowBox[{"(", 
             RowBox[{"psi", "-", "1"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"NN", "[", "ttbc", "]"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"psi", "-", "2"}], ")"}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"NN", "[", "ttbc", "]"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"psi", "-", "1"}], ")"}]}], ")"}], "*", "delta", "*", 
            " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"ttbc", "+", "b"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"delta", "+", "1"}], ")"}]}], ")"}]}], ")"}]}]}], 
          ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"theta", "*", 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ttbc", "+", "b"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"-", "delta"}], ")"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "theta"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"NN", "[", "ttbc", "]"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"psi", "-", "1"}], ")"}]}], ")"}]}]}], ")"}], "^", 
        "2"}], ")"}]}], ")"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "mkt1", " ", "consumption", " ", "for", " ", "generic", " ", "interest", 
     " ", "rate", " ", "in", " ", "LW", " ", 
     RowBox[{"W", "/", " ", "BARGAINING"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"qbc", ":=", 
    RowBox[{"ttbc", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ttbc", "+", "b"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"-", "delta"}], ")"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"Phiprimebcc", "[", "ttbc", "]"}], "*", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "-", "alpha"}], ")"}], "/", "A"}]}], ")"}]}]}], 
          "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"nB", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"alpha", "*", "ttbc", "*", 
              RowBox[{"Phiprimebcc", "[", "ttbc", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"A", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"NN", "[", "ttbc", "]"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"psi", "-", "1"}], ")"}]}], ")"}]}], ")"}]}]}], 
          "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ttbc", ",", "0.1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"nB", ",", "0.1"}], "}"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"nBbc", ":=", 
    RowBox[{"nB", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ttbc", "+", "b"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"-", "delta"}], ")"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"Phiprimebcc", "[", "ttbc", "]"}], "*", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mu", "/", "beta"}], "-", "1"}], ")"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "-", "alpha"}], ")"}], "/", "A"}]}], ")"}]}]}], 
          "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"nB", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"alpha", "*", "ttbc", "*", 
              RowBox[{"Phiprimebcc", "[", "ttbc", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"A", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"NN", "[", "ttbc", "]"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"psi", "-", "1"}], ")"}]}], ")"}]}], ")"}]}]}], 
          "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ttbc", ",", "0.1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"nB", ",", "0.1"}], "}"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"welfare", " ", "in", " ", "LW"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"wbc", ":=", 
    RowBox[{
     RowBox[{"alpha", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", "qbc", ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "-", "delta"}], ")"}]}], "-", 
          RowBox[{"(", 
           RowBox[{"b", "^", 
            RowBox[{"(", 
             RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", "delta"}], ")"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "alpha"}], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"qbc", "+", "nBbc"}], ")"}], "^", "psi"}], ")"}], "/", 
       "psi"}]}], "+", 
     RowBox[{"DD", "*", 
      RowBox[{"Log", "[", "DD", "]"}]}], "-", "DD"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<PLOT welfare in LW and BC w/ bargaining\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"image", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"wbc", ",", "wlw"}], "}"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mu", ",", " ", "muF", ",", "mumax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", " ", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<inflation\>\"", ",", " ", "\"\<welfare\>\""}], "}"}]}], 
      ",", " ", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<BC\>\"", ",", "\"\<LW\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<PRINT welfare IN LW\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Print", "[", "wlw", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"mu", ",", " ", "muF", ",", "3", ",", "0.0001"}], "}"}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<PRINT welfare IN BC\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Print", "[", "wbc", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"mu", ",", " ", "muF", ",", "3", ",", "0.0001"}], "}"}]}], 
    "]"}]}]}]], "Input",ExpressionUUID->"8a2c9fab-6518-4b3b-b321-\
9519683e26aa"]
},
WindowSize->{1904, 1037},
WindowMargins->{{1910, Automatic}, {Automatic, 18}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 19664, 548, 1245, "Input",ExpressionUUID->"8a2c9fab-6518-4b3b-b321-9519683e26aa"]
}
]
*)

(* End of internal cache information *)

